@@ -56,6 +56,8 @@ class CreateReactLoader(object):
                 'the asset-manifest file in the build directory and the path is correct?')
 
     def get_assets(self):
+        if self.manifest_path:
+            return self.get_prod_assets()
         if self.is_dev:
             return self.get_dev_assets()
         return self.get_prod_assets()
